#!/usr/bin/env python
# coding: utf-8

# # Doublet Detection on 8k PBMCs from 10x Genomics

# In[1]:


import numpy as np
import doubletdetection
import tarfile
import time
import matplotlib.pyplot as plt
import sys
import os
import pandas as pd

plt.ioff()
#ioff()


# ### Load Count Matrix

# In[3]:

#sampleID = "SVI-030-18"
n_iter = 50
sampleID = "tung"
out_dir = "doublets/"
#matrix_path = datapath + 'outs/filtered_feature_bc_matrix/matrix.mtx.gz'
matrix_path = "data/tung/molecules.txt"
#raw_counts = doubletdetection.load_mtx(matrix_path)
raw_counts =  pd.read_csv(matrix_path, sep='\t', header=0)
raw_counts = raw_counts.T
# Remove columns with all 0s
zero_genes = np.sum(raw_counts, axis=0) == 0
raw_counts = raw_counts.values[:, ~zero_genes]


# ## Run Doublet Detection

# Right now, PhenoGraph is a bit talkative, so we capture the output to avoid lots of text

# In[4]:


clf = doubletdetection.BoostClassifier(n_iters = n_iter)
 
start = time.time()
doublets = clf.fit(raw_counts).predict(p_thresh=1e-7, voter_thresh=0.8)
end = time.time()


np.savetxt(out_dir +"tung.dbls.txt", doublets)

# In[5]:


print('Time elapsed: {:.2f} seconds, {:.2f}sec/iteration, for {} iterations'.format(end-start, (end-start) / clf.n_iters, clf.n_iters))


# ## Visualize Results

# ### Convergence of doublet calls

# In[6]:


f = doubletdetection.plot.convergence(clf, save=(out_dir+sampleID+'convergence_test.pdf'), show=True, p_thresh=1e-7, voter_thresh=0.8)


# ### Doublets on tSNE map

# In[7]:


f2, tsne_coords, clusters = doubletdetection.plot.tsne(raw_counts, doublets, random_state=1, 
                                                       save=(out_dir+sampleID+'double.pdf'), show=True)


# ### Number of predicted doublets at different threshold combinations

# In[8]:


f3 = doubletdetection.plot.threshold(clf, save=(out_dir+sampleID+'threshold_test.pdf'), show=True, p_step=6)

