---
output: html_document
---

## Exercise: Expression QC (Reads)




```r
library(SingleCellExperiment)
library(scater)
options(stringsAsFactors = FALSE)
```


```r
reads <- read.table("data/tung/reads.txt", sep = "\t")
anno <- read.table("data/tung/annotation.txt", sep = "\t", header = TRUE)
```


```r
head(reads[ , 1:3])
```

```
##                 NA19098.r1.A01 NA19098.r1.A02 NA19098.r1.A03
## ENSG00000237683              0              0              0
## ENSG00000187634              0              0              0
## ENSG00000188976             57            140              1
## ENSG00000187961              0              0              0
## ENSG00000187583              0              0              0
## ENSG00000187642              0              0              0
```

```r
head(anno)
```

```
##   individual replicate well      batch      sample_id
## 1    NA19098        r1  A01 NA19098.r1 NA19098.r1.A01
## 2    NA19098        r1  A02 NA19098.r1 NA19098.r1.A02
## 3    NA19098        r1  A03 NA19098.r1 NA19098.r1.A03
## 4    NA19098        r1  A04 NA19098.r1 NA19098.r1.A04
## 5    NA19098        r1  A05 NA19098.r1 NA19098.r1.A05
## 6    NA19098        r1  A06 NA19098.r1 NA19098.r1.A06
```


```r
reads <- SingleCellExperiment(
    assays = list(counts = as.matrix(reads)), 
    colData = anno
)
```


```r
keep_feature <- rowSums(counts(reads) > 0) > 0
reads <- reads[keep_feature, ]
```


```r
isSpike(reads, "ERCC") <- grepl("^ERCC-", rownames(reads))
isSpike(reads, "MT") <- rownames(reads) %in% 
    c("ENSG00000198899", "ENSG00000198727", "ENSG00000198888",
    "ENSG00000198886", "ENSG00000212907", "ENSG00000198786",
    "ENSG00000198695", "ENSG00000198712", "ENSG00000198804",
    "ENSG00000198763", "ENSG00000228253", "ENSG00000198938",
    "ENSG00000198840")
```


```r
reads <- calculateQCMetrics(
    reads,
    feature_controls = list(
        ERCC = isSpike(reads, "ERCC"), 
        MT = isSpike(reads, "MT")
    )
)
```

```
## Warning in calculateQCMetrics(reads, feature_controls = list(ERCC =
## isSpike(reads, : spike-in set 'ERCC' overwritten by feature_controls set of
## the same name
```


```r
hist(
    reads$total_counts,
    breaks = 100
)
abline(v = 1.3e6, col = "red")
```

<div class="figure" style="text-align: center">
<img src="exprs-qc-reads_files/figure-html/total-counts-hist-reads-1.png" alt="Histogram of library sizes for all cells" width="90%" />
<p class="caption">(\#fig:total-counts-hist-reads)Histogram of library sizes for all cells</p>
</div>


```r
filter_by_total_counts <- (reads$total_counts > 1.3e6)
```


```r
table(filter_by_total_counts)
```

```
## filter_by_total_counts
## FALSE  TRUE 
##   180   684
```


```r
hist(
    reads$total_features_by_counts,
    breaks = 100
)
abline(v = 7000, col = "red")
```

<div class="figure" style="text-align: center">
<img src="exprs-qc-reads_files/figure-html/total-features-hist-reads-1.png" alt="Histogram of the number of detected genes in all cells" width="90%" />
<p class="caption">(\#fig:total-features-hist-reads)Histogram of the number of detected genes in all cells</p>
</div>


```r
filter_by_expr_features <- (reads$total_features_by_counts > 7000)
```


```r
table(filter_by_expr_features)
```

```
## filter_by_expr_features
## FALSE  TRUE 
##   116   748
```


```r
plotColData(
    reads,
    x = "total_features_by_counts",
    y = "pct_counts_MT",
    colour = "batch"
)
```

<div class="figure" style="text-align: center">
<img src="exprs-qc-reads_files/figure-html/mt-vs-counts-reads-1.png" alt="Percentage of counts in MT genes" width="90%" />
<p class="caption">(\#fig:mt-vs-counts-reads)Percentage of counts in MT genes</p>
</div>


```r
plotColData(
    reads,
    x = "total_features_by_counts",
    y = "pct_counts_ERCC",
    colour = "batch"
)
```

<div class="figure" style="text-align: center">
<img src="exprs-qc-reads_files/figure-html/ercc-vs-counts-reads-1.png" alt="Percentage of counts in ERCCs" width="90%" />
<p class="caption">(\#fig:ercc-vs-counts-reads)Percentage of counts in ERCCs</p>
</div>


```r
filter_by_ERCC <- 
    reads$batch != "NA19098.r2" & reads$pct_counts_ERCC < 25
table(filter_by_ERCC)
```

```
## filter_by_ERCC
## FALSE  TRUE 
##   103   761
```

```r
filter_by_MT <- reads$pct_counts_MT < 30
table(filter_by_MT)
```

```
## filter_by_MT
## FALSE  TRUE 
##    18   846
```


```r
reads$use <- (
    # sufficient features (genes)
    filter_by_expr_features &
    # sufficient molecules counted
    filter_by_total_counts &
    # sufficient endogenous RNA
    filter_by_ERCC &
    # remove cells with unusual number of reads in MT genes
    filter_by_MT
)
```


```r
table(reads$use)
```

```
## 
## FALSE  TRUE 
##   258   606
```


```r
reads <- runPCA(
    reads,
    use_coldata = TRUE, 
    detect_outliers = TRUE
)
reducedDimNames(reads)
```

```
## [1] "PCA_coldata"
```


```r
table(reads$outlier)
```

```
## 
## FALSE  TRUE 
##   753   111
```


```r
plotReducedDim(
    reads,
    use_dimred = "PCA_coldata",
    size_by = "total_features_by_counts", 
    shape_by = "use", 
    colour_by = "outlier"
)
```

<img src="exprs-qc-reads_files/figure-html/unnamed-chunk-16-1.png" width="90%" style="display: block; margin: auto;" />


```r
library(limma)
```

```
## 
## Attaching package: 'limma'
```

```
## The following object is masked from 'package:scater':
## 
##     plotMDS
```

```
## The following object is masked from 'package:BiocGenerics':
## 
##     plotMA
```

```r
auto <- colnames(reads)[reads$outlier]
man <- colnames(reads)[!reads$use]
venn.diag <- vennCounts(
    cbind(colnames(reads) %in% auto,
    colnames(reads) %in% man)
)
vennDiagram(
    venn.diag,
    names = c("Automatic", "Manual"),
    circle.col = c("blue", "green")
)
```

<div class="figure" style="text-align: center">
<img src="exprs-qc-reads_files/figure-html/cell-filt-comp-reads-1.png" alt="Comparison of the default, automatic and manual cell filters" width="90%" />
<p class="caption">(\#fig:cell-filt-comp-reads)Comparison of the default, automatic and manual cell filters</p>
</div>


```r
plotHighestExprs(reads, exprs_values = "counts")
```

<div class="figure" style="text-align: center">
<img src="exprs-qc-reads_files/figure-html/top50-gene-expr-reads-1.png" alt="Number of total counts consumed by the top 50 expressed genes" width="90%" />
<p class="caption">(\#fig:top50-gene-expr-reads)Number of total counts consumed by the top 50 expressed genes</p>
</div>


```r
keep_feature <- nexprs(
  reads[,colData(reads)$use], 
  byrow = TRUE, 
  detection_limit = 1
) >= 2
rowData(reads)$use <- keep_feature
```


```r
table(keep_feature)
```

```
## keep_feature
## FALSE  TRUE 
##  2664 16062
```


```r
dim(reads[rowData(reads)$use, colData(reads)$use])
```

```
## [1] 16062   606
```


```r
assay(reads, "logcounts_raw") <- log2(counts(reads) + 1)
reducedDim(reads) <- NULL
```


```r
saveRDS(reads, file = "data/tung/reads.rds")
```

By comparing Figure \@ref(fig:cell-filt-comp) and Figure \@ref(fig:cell-filt-comp-reads), it is clear that the reads based filtering removed more cells than the UMI based analysis. If you go back and compare the results you should be able to conclude that the ERCC and MT filters are more strict for the reads-based analysis.


```r
sessionInfo()
```

```
## R version 3.6.0 (2019-04-26)
## Platform: x86_64-pc-linux-gnu (64-bit)
## Running under: Ubuntu 18.04.3 LTS
## 
## Matrix products: default
## BLAS:   /usr/lib/x86_64-linux-gnu/blas/libblas.so.3.7.1
## LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.7.1
## 
## locale:
##  [1] LC_CTYPE=en_AU.UTF-8       LC_NUMERIC=C              
##  [3] LC_TIME=en_AU.UTF-8        LC_COLLATE=en_AU.UTF-8    
##  [5] LC_MONETARY=en_AU.UTF-8    LC_MESSAGES=en_AU.UTF-8   
##  [7] LC_PAPER=en_AU.UTF-8       LC_NAME=C                 
##  [9] LC_ADDRESS=C               LC_TELEPHONE=C            
## [11] LC_MEASUREMENT=en_AU.UTF-8 LC_IDENTIFICATION=C       
## 
## attached base packages:
## [1] parallel  stats4    stats     graphics  grDevices utils     datasets 
## [8] methods   base     
## 
## other attached packages:
##  [1] limma_3.40.6                scater_1.12.2              
##  [3] ggplot2_3.2.1               SingleCellExperiment_1.6.0 
##  [5] SummarizedExperiment_1.14.1 DelayedArray_0.10.0        
##  [7] BiocParallel_1.18.1         matrixStats_0.55.0         
##  [9] Biobase_2.44.0              GenomicRanges_1.36.1       
## [11] GenomeInfoDb_1.20.0         IRanges_2.18.3             
## [13] S4Vectors_0.22.1            BiocGenerics_0.30.0        
## 
## loaded via a namespace (and not attached):
##   [1] ggbeeswarm_0.6.0         colorspace_1.4-1        
##   [3] mvoutlier_2.0.9          class_7.3-15            
##   [5] modeltools_0.2-22        rio_0.5.16              
##   [7] mclust_5.4.5             XVector_0.24.0          
##   [9] pls_2.7-1                BiocNeighbors_1.2.0     
##  [11] cvTools_0.3.2            flexmix_2.3-15          
##  [13] mvtnorm_1.0-11           ranger_0.11.2           
##  [15] splines_3.6.0            sROC_0.1-2              
##  [17] robustbase_0.93-5        knitr_1.25              
##  [19] zeallot_0.1.0            robCompositions_2.1.0   
##  [21] kernlab_0.9-27           cluster_2.1.0           
##  [23] rrcov_1.4-7              compiler_3.6.0          
##  [25] backports_1.1.4          assertthat_0.2.1        
##  [27] Matrix_1.2-17            lazyeval_0.2.2          
##  [29] BiocSingular_1.0.0       htmltools_0.3.6         
##  [31] tools_3.6.0              rsvd_1.0.2              
##  [33] gtable_0.3.0             glue_1.3.1              
##  [35] GenomeInfoDbData_1.2.1   dplyr_0.8.3             
##  [37] Rcpp_1.0.2               carData_3.0-2           
##  [39] cellranger_1.1.0         zCompositions_1.3.2-1   
##  [41] vctrs_0.2.0              sgeostat_1.0-27         
##  [43] fpc_2.2-3                DelayedMatrixStats_1.6.1
##  [45] lmtest_0.9-37            xfun_0.9                
##  [47] laeken_0.5.0             stringr_1.4.0           
##  [49] openxlsx_4.1.0.1         lifecycle_0.1.0         
##  [51] irlba_2.3.3              DEoptimR_1.0-8          
##  [53] zlibbioc_1.30.0          MASS_7.3-51.1           
##  [55] zoo_1.8-6                scales_1.0.0            
##  [57] VIM_4.8.0                hms_0.5.1               
##  [59] RColorBrewer_1.1-2       yaml_2.2.0              
##  [61] curl_4.2                 NADA_1.6-1              
##  [63] gridExtra_2.3            reshape_0.8.8           
##  [65] stringi_1.4.3            highr_0.8               
##  [67] pcaPP_1.9-73             e1071_1.7-2             
##  [69] boot_1.3-20              zip_2.0.4               
##  [71] truncnorm_1.0-8          rlang_0.4.0             
##  [73] pkgconfig_2.0.3          prabclus_2.3-1          
##  [75] bitops_1.0-6             evaluate_0.14           
##  [77] lattice_0.20-38          purrr_0.3.2             
##  [79] labeling_0.3             cowplot_1.0.0           
##  [81] tidyselect_0.2.5         GGally_1.4.0            
##  [83] plyr_1.8.4               magrittr_1.5            
##  [85] bookdown_0.13            R6_2.4.0                
##  [87] pillar_1.4.2             haven_2.1.1             
##  [89] foreign_0.8-70           withr_2.1.2             
##  [91] survival_2.43-3          abind_1.4-5             
##  [93] RCurl_1.95-4.12          sp_1.3-1                
##  [95] nnet_7.3-12              tibble_2.1.3            
##  [97] crayon_1.3.4             car_3.0-3               
##  [99] rmarkdown_1.15           viridis_0.5.1           
## [101] grid_3.6.0               readxl_1.3.1            
## [103] data.table_1.12.2        forcats_0.4.0           
## [105] diptest_0.75-7           vcd_1.4-4               
## [107] digest_0.6.21            tidyr_1.0.0             
## [109] munsell_0.5.0            beeswarm_0.2.3          
## [111] viridisLite_0.3.0        vipor_0.4.5
```
