--- 
title: "Analysis of single cell RNA-seq data"
author: "Ruqian Lyu, PuXue Qiao, and Davis J. McCarthy (<a href = 'https://twitter.com/davisjmcc'>davisjmcc</a>)"
date: "2019-10-03"
#knit: "bookdown::render_book"
documentclass: book
bibliography: [book.bib]
biblio-style: apalike
link-citations: yes
always_allow_html: yes
---

This version of the course builds on the May 2019 version of the course authored
by: Vladimir Kiselev (<a href = 'https://twitter.com/wikiselev'>wikiselev</a>),
Tallulah Andrews (<a href = 'https://twitter.com/talandrews'>talandrews</a>),
Davis J. McCarthy (<a href = 'https://twitter.com/davisjmcc'>davisjmcc</a>),
Jennifer Westoby (<a href =
'https://twitter.com/Jenni_Westoby'>Jenni_Westoby</a>), Maren Büttner (<a href =
'https://twitter.com/marenbuettner'>marenbuettner</a>), Jimmy Lee (<a href =
'https://twitter.com/THJimmyLee'>THJimmyLee</a>), Krzysztof Polanski, Sebastian
Y. Müller, Elo Madissoon, Stephane Ballereau, Maria Do Nascimento Lopes Primo,
Rocio Martinez Nunez and Martin Hemberg (<a href =
'https://twitter.com/m_hemberg'>m_hemberg</a>)

# About the course

<!-- > > <span style="color:red">__Important!__ The course will be run on the __2nd - 3rd October 2019, both days 9:00-17:00 Melbourne, Australia time__. </span> -->

Today it is possible to obtain genome-wide transcriptome data from single cells
using high-throughput sequencing (scRNA-seq). The cellular resolution and the
genome-wide scope of scRNA-seq makes it possible to address issues that are
intractable using other methods like bulk RNA-seq or single-cell RT-qPCR.
However, scRNA-seq data poses many challenges due to the scale and complexity of
scRNA-seq datasets, with novel methods often required to account for the
particular characteristics of the data.

In this course we will discuss some of the questions that can be addressed using
scRNA-seq as well as the available computational and statistical methods. We
will cover key features of the technology platforms and fundamental principles
of scRNA-seq data analysis that are transferable across technologies and
analysis workflows. The number of computational tools is already vast and
increasing rapidly, so we provide hands-on workflows using some of our favourite
tools on carefully selected, biologically-relevant example datasets. 

Across two days, attendees can expect to gain an understanding of approaches to
and practical analysis experience on: quality control, data normalisation,
visualisation, clustering, trajectory (pseudotime) inference, differential
expression, batch correction and data integration.


Course outline:

- Day 1: 

  + Morning session 1: Workshop overview; introduction to scRNA-seq; pre-processing scRNA-seq data
  + Morning session 2: Quality control, visualisation and exploratory data analysis
  + Afternoon session 1: Normalisation, confounders and batch correction
  + Afternoon session 2: Latent spaces, clustering and cell annotation

- Day 2: 

  + Morning session 1: Trajectory inference
  + Morning session 2: Differential expression; data imputation
  + Afternoon session 1: Combining datasets and data integration
  + Afternoon session 2: Case studies

This course has been adapted from a course taught through the University of
Cambridge Bioinformatics training unit, but the material is meant for anyone
interested in learning about computational analysis of scRNA-seq data and is
updated roughly twice per year.


The number of computational tools is increasing rapidly and we are doing our
best to keep up to date with what is available. One of the main constraints for
this course is that we would like to use tools that are implemented in R and
that run reasonably fast. Moreover, we will also confess to being somewhat
biased towards methods that have been developed either by us or by our friends
and colleagues.

## Web page

The html version of the workshop material is available at the following link:

__[https://biocellgen-public.svi.edu.au/mig_2019_scrnaseq-workshop/public/index.html](https://biocellgen-public.svi.edu.au/mig_2019_scrnaseq-workshop/public/index.html)__

## GitLab

The source code and materials for the course are available at the SVI
Bioinformatics and Cellular Genomics Lab's GitLab:

__[https://gitlab.svi.edu.au/biocellgen-public/mig_2019_scrnaseq-workshop](https://gitlab.svi.edu.au/biocellgen-public/mig_2019_scrnaseq-workshop)__


## Video

This video was recorded during the course (2 days) in May 2019 in Cambridge, UK.
This recorded version of the course differs slightly from the version in this
document.

### Day 1

<iframe width="560" height="315" src="https://www.youtube.com/embed/thHgPqQpkE4" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

### Day 2

<iframe width="560" height="315" src="https://www.youtube.com/embed/7dQ_pleDO2Y" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

## Docker image

The course can be reproduced without any package installation by running the
course docker image which contains all the required packages.

__[Workshop Docker Repository on DockerHub](https://hub.docker.com/r/svibiocellgen/mig_2019_scrnaseq-workshop/)__


### Run the image

Make sure Docker is installed on your system. If not, please follow [these
instructions](https://docs.docker.com/engine/installation/). To run the course
docker image (use [the latest
version](https://hub.docker.com/r/svibiocellgen/mig_2019_scrnaseq-workshop?tab=tags)):

```
docker run -p 8888:8888 -e PASSWORD="jupyter" svibiocellgen/mig_2019_scrnaseq-workshop:v1.01
```

Then follow the instructions provided, e.g.:
```
To access the notebook, open this file in a browser:
    file:///home/jovyan/.local/share/jupyter/runtime/nbserver-6-open.html
Or copy and paste one of these URLs:
    http://(a9ee1aad5398 or 127.0.0.1):8888/?token=22debff49d9aae3c50e6b0b5241b47eefb1b8f883fcb7e6d
```

A Jupyter session will be open in a web browser (we recommend Chrome).

#### Windows users

On Windows operating system the IP address of the container can be different
from `127.0.0.1` (`localhost`). To find the IP address please run:
```
docker-machine ip default
```

### Download data/other files


#### Download from AWS (within Docker)

__Recommended if you are using Docker__

In the Jupyter session, please click on `New -> Terminal`. In the new terminal
window please run:

```
./poststart.sh
```

#### Manual download from AWS

If you want to download data files from AWS outside of Docker image you can
still use the same `poststart.sh` script but you will need to install [AWS
CLI](https://docs.aws.amazon.com/cli/latest/userguide/install-bundle.html) on
your computer.

Alternatively, you can browse and download the files in you web-browser by
visiting [this
link](https://scrnaseq-course.cog.sanger.ac.uk/index.html?prefix=data/).

NB: Only the core datasets (i.e. not Tabula Muris) are available from AWS storage.

#### Manual download from SVI

__Recommended if you are using your own computer__

For simplicity, we have also hosted the core datasets used in the course and a
subset of the [Tabula Muris](https://tabula-muris.ds.czbiohub.org/) data on SVI
websites. There are two files to download, both "tarballs", i.e. compressed
archives of multiple folders and files.

##### Core datasets

To download the core datasets, click [this
link](https://www.svi.edu.au/MIG_2019_scRNAseq-workshop/mig-sc-workshop-2019-data.tar.gz)
(195Mb).

It is most convenient to download the tarball to the head directory for the
course. We then want to unpack the tarball and move it to a directory called
`data` in the head directory of the repository. 

To do this at the command line:

```
wget https://www.svi.edu.au/MIG_2019_scRNAseq-workshop/mig-sc-workshop-2019-data.tar.gz
mkdir workshop-data
tar -xvf mig-sc-workshop-2019-data.tar.gz --directory workshop-data
mv workshop-data/mnt/mcfiles/Datasets/MIG_2019_scRNAseq-workshop/data ./
rm -r workshop-data
```

[This requires a little bit of faff to get all of the directory paths correct
and then tidy updated.]

Alternatively, if you are working on your laptop, unpack the tarball using the
default method on your system (usually a double click on the `*.tar.gz` file
will do the trick) and drag and drop the `data` folder to the workshop directory.

##### Tabula Muris

To download the Tabula Muris data, clink [this
link](https://www.svi.edu.au/MIG_2019_scRNAseq-workshop/Tabula_Muris.tar.gz)
(655Mb).

We then go through a similar process as described above to unpack the tarball.

```
wget https://www.svi.edu.au/MIG_2019_scRNAseq-workshop/Tabula_Muris.tar.gz
tar -xvf Tabula_Muris.tar.gz
mv mnt/mcfiles/Datasets/Tabula_Muris data
rm -r mnt
```

##### Desired results

The data folder then should contain both the core datasets and the Tabula Muris
data, and have the following structure:

```
data
├── 10cells_barcodes.txt
├── 2000_reference.transcripts.fa
├── deng
│   └── deng-reads.rds
├── droplet_id_example_per_barcode.txt.gz
├── droplet_id_example_truth.gz
├── EXAMPLE.cram
├── pancreas
│   ├── muraro.rds
│   └── segerstolpe.rds
├── pbmc3k_filtered_gene_bc_matrices
│   └── hg19
│       ├── barcodes.tsv
│       ├── genes.tsv
│       └── matrix.mtx
├── sce
│   ├── Heart_10X.rds
│   └── Thymus_10X.rds
├── Tabula_Muris
│   ├── droplet
│   │   ├── droplet
│   │   ├── droplet_annotation.csv
│   │   └── droplet_metadata.csv
│   └── FACS_smartseq2
│       ├── FACS
│       ├── FACS_annotations.csv
│       └── FACS_metadata.csv
└── tung
    ├── annotation.txt
    ├── molecules.txt
    ├── reads.txt
    ├── TNs.txt
    └── TPs.txt

11 directories, 22 files
```

With the files in these locations, everything is set up to run the code as
presented in the RMarkdown files in the workshop.

### RStudio

Now go back to Jupyter browser tab and change word `tree` in the url to
`rstudio`. RStudio server will open with all of the course files, software and
the data folder available.

## Manual installation

If you are not using a docker image of the course, then to be able to run all
code chunks of the course you need to clone or download the [course GitHub
repository](https://github.com/hemberg-lab/scRNA.seq.course) and start an R
session in the `course_files` folder. You will also need to install all required
packages manually. We are using *Bioconductor version 3.9* packages in this
version of the course.

The `install.R` file in the workshop repository provides the necessary commands
for installing all of the required packages. You can run this script from the
command line with `Rscript install.R` or copy-and-paste the commands into an R
session and run them interactively.

Alternatively, you can just install packages listed in a chapter of interest.

## Citation

This version of the workshop has been updated by Davis J. McCarthy, Ruqian Lyu
and PuXue Qiao, based on the 2019-07-01 version of the course:

- Ruqian Lyu, PuXue Qiao, Vladimir Kiselev, Tallulah Andrews, Jennifer Westoby,
  Maren Büttner, Jimmy Lee, Krzysztof Polanski, Sebastian Y. Müller, Elo
  Madissoon, Stephane Ballereau, Maria Do Nascimento Lopes Primo, Rocio Martinez
  Nunez, Martin Hemberg and Davis J. McCarthy, (2019), "Analysis of single cell
  RNA-seq data", https://scrnaseq-course.cog.sanger.ac.uk/website/index.html

## License

All of the course material is licensed under <b>GPL-3</b>. Anyone is welcome to
go through the material in order to learn about analysis of scRNA-seq data. If
you plan to use the material for your own teaching, we would appreciate if you
tell us about it in addition to providing a suitable citation.

## Prerequisites

The course is intended for those who have basic familiarity with Unix and the R
statistical language.

We will also assume that you are familiar with mapping and analysing bulk
RNA-seq data as well as with the commonly available computational tools.

We recommend attending the [Introduction to RNA-seq and ChIP-seq data
analysis](http://training.csx.cam.ac.uk/bioinformatics/search) or the [Analysis
of high-throughput sequencing data with
Bioconductor](http://training.csx.cam.ac.uk/bioinformatics/search) before
attending this course.

## Contact

If you have any __comments__, __questions__ or __suggestions__ about the
material, please contact <a href="mailto:dmccarthy@svi.edu.au">Davis McCarthy</a>.


