---
output: html_document
---



# Processing raw scRNA-seq data

## Generating fastq files from BCLs

BCLs (Illumina sequencer's base call files) are binary files with raw sequencing
data generated from sequencers. If your data processing starts BCLs you will
need to make fastq files from the BCL files. [More on BCL
format](https://sapac.illumina.com/informatics/sequencing-data-analysis/sequence-file-formats.html).
For others, you may have received the fastq files from your sequencing
facilities or collaborators, you can refer to `Section 5.2` for pre-processing
on fastq files.

### Demultiplexing 

In cases where multiple sample libraries are pooled together for sequencing on
one lane of a flowcell to reduce seqeuncing cost, we demultiplex the samples by
their sample index in the step of making fastq files from BCLs. Sample indices
are 'barcodes' for multiplexed samples which have been constructed in the read
structure during the library preparation.

<div class="figure" style="text-align: center">
<img src="./figures/10x_read_structure.png" alt="Example 10X Final Library Structure" width="90%" />
<p class="caption">(\#fig:unnamed-chunk-2)Example 10X Final Library Structure</p>
</div>


### cellranger mkfastq

If you are working with 10X Genomiec data, it is best to use the `cellranger
mkfastq` pipleline, which wraps Illumina's `bcl2fastq` and provides a number of
convenient features designed specifically for 10X data format. In order to
demultiplex samples, you would also need the `sample_sheet.csv` file which tells
the mkfastq pipeline which libraries are sequenced on which lanes of the
flowcell and what sample index sets they have. For example when you have
multiple libraries sequenced on one lane here: ![Figure
2](https://support.10xgenomics.com/img/mkfastq-1.png)

With `cellranger mkfastq`, you can provide a `simpleSampleSheet.csv` file that has:

```
Lane    Sample    Index
1    test_sample	SI-P03-C9
1    test_sample2	SI-P03-A3
...

```

`SI-P03-C9` and `SI-P03-A3` are the 10x sample index set names. Each of them
corresponds to a mix of 4 unique oligonucleotides so that the i7 index read is
balanced across all 4 bases during sequencing. There are a list of 96 sample
index sets and you can use any ones of them to 'tag' your samples.

An example command to run `cellranger mkfastq`

```
/mnt/Software/cellranger/cellranger-3.0.2/cellranger mkfastq \
        --run ./input.runs.folder/ --samplesheet {input.samplesheet.csv} \
        --id run_id \
        --qc --project MAXL_2019_LIM_organoid_RNAseq \
        --output-dir data/fastq_path/ \
        --jobmode=local --localcores=20 --localmem=50 1> {log}


```
After `mkfastq`, you end up with each sample's fastq files from each sequencing lanes:

```
test_sample_S1_L001_I1_001.fastq.gz
test_sample_S1_L001_R1_001.fastq.gz
test_sample_S1_L001_R2_001.fastq.gz
test_sample2_S2_L001_I1_001.fastq.gz
test_sample2_S2_L001_R1_001.fastq.gz
test_sample2_S2_L001_R2_001.fastq.gz

```

### Illumina bcl2fastq

You can also use Illumina's `bcl2fastq` tool directly and it is more generally
applicable. `bcf2fastq` converts BCLs to fastqs while optionally demultiplexing
sequencing data. Find the documentation of the tool
[here](http://sapac.support.illumina.com/content/dam/illumina-support/documents/documentation/software_documentation/bcl2fastq/bcl2fastq2-v2-20-software-guide-15051736-03.pdf);
[training videos](http://sapac.support.illumina.com/training.html?langsel=/au/)
may also help to come to grips with using this tool.

<div class="figure" style="text-align: center">
<img src="./figures/illumina-demultiplexing.jpg" alt="Sample Demultiplexing" width="90%" />
<p class="caption">(\#fig:unnamed-chunk-3)Sample Demultiplexing</p>
</div>

You will need to supply a `SampleSheet.csv` file like this:
<div class="figure" style="text-align: center">
<img src="./figures/samplesheet-illumina.png" alt="SampleSheet.csv file" width="90%" />
<p class="caption">(\#fig:unnamed-chunk-4)SampleSheet.csv file</p>
</div>

This information should come from your sequencing facilities. Running
`bcl2fastq` can then be done like this:


```
/usr/local/bin/bcl2fastq --runfolder-dir <RunFolder>
--output-dir <BaseCalls>

```

The output fastq files are names as
`SampleName_SampleNumber_Lane_Read_001.fastq.gz` same with `cellranger mkfastq`
output. (eg: `Sample1_S1_L001_R1_001.fastq.gz`)


